#' @title Countries and Country Codes 
#' @description Countries and country codes in EU,
#' Euro area, EFTA and EU candidate countries.
#' @format A data_frame:
#' \describe{
#'   \item{code}{Country code in the Eurostat database}
#'   \item{name}{Country name in English}
#' }
#' @source \url{http://ec.europa.eu/eurostat/statistics-explained/index.php/Tutorial:Country_codes_and_protocol_order},
#'   \url{http://ec.europa.eu/eurostat/statistics-explained/index.php/Glossary:Euro_area}
"eu_countries" 

#' @rdname eu_countries
"ea_countries" 

#' @rdname eu_countries
"efta_countries"

#' @rdname eu_countries
"eu_candidate_countries"
